import os
from requests import get
from socket import gethostbyname

from colorama import Fore

from .menu import input_wait, set_readline, tools_cli
from .config import install_dir
from .hosts import get_hosts, add_host
from .utility import Utility


class print_contributors(Utility):
    def run(self):
        print(Fore.RED + """
    8888b.  888888 Yb    dP .dP"Y8 
    8I  Yb 88__    Yb  dP  `Ybo." 
    8I  dY 88""     YbdP   o.`Y8b 
    8888Y"  888888    YP    8bodP'
    """)
        response = get(
            'https://api.github.com/repos/fsociety-team/fsociety/contributors')
        contributors = response.json()
        for contributor in sorted(contributors, key=lambda c: c['contributions'], reverse=True):
            username = contributor.get("login")
            print(f" {username} ".center(30, "-"))
        print(Fore.RESET)
        input_wait()


class spawn_shell(Utility):
    def run(self):
        print("Enter `exit` to return to fsociety")
        shell = os.getenv("SHELL")
        os.chdir(install_dir)
        os.system(shell)


class host2ip(Utility):
    def run(self):
        hosts = get_hosts()
        set_readline(hosts)
        user_host = input("\nEnter a host: ").strip()
        if not user_host in hosts:
            add_host(user_host)
        ip = gethostbyname(user_host)
        print(f"\n{user_host} has the IP of {ip}")


tools = [host2ip, spawn_shell, print_contributors]

__tools__ = dict()
for tool in tools:
    __tools__[tool.__name__] = tool


def cli():
    tools_cli(__name__, __tools__)



# Core
from fsociety.core.menu import tools_cli

from .nmap import nmap
from .sqlmap import sqlmap
from .sublist3r import sublist3r
from .sherlock import sherlock
from .s3scanner import s3scanner

__tools__ = {
    "nmap": nmap,
    "sqlmap": sqlmap,
    "sublist3r": sublist3r,
    "sherlock": sherlock,
    "s3scanner": s3scanner
}


def cli():
    tools_cli(__name__, __tools__)



import os

from fsociety.core.repo import GitHubRepo
from fsociety.core.menu import confirm


class cuteitRepo(GitHubRepo):
    def __init__(self, path="D4Vinci/Cuteit", install=None):
        super().__init__(path=path, install=install)

    def run(self):
        os.chdir(self.full_path)
        user_ip = input("\nEnter a ip: ").strip()
        return os.system(f"python3 Cuteit.py {user_ip}")


cuteit = cuteitRepo()



import os

from fsociety.core.repo import GitHubRepo
from fsociety.core.menu import set_readline
from fsociety.core.usernames import get_usernames, add_username


class sherlockRepo(GitHubRepo):
    def __init__(self, path="sherlock-project/sherlock", install={"pip": "requirements.txt"}):
        super().__init__(path=path, install=install)

    def run(self):
        os.chdir(self.full_path)
        usernames = get_usernames()
        set_readline(usernames)
        user_usernames = input("\nEnter one or more usernames: ").strip()
        for username in user_usernames.split():
            if not username in usernames:
                add_username(username)
        return os.system(f"python3 sherlock {user_usernames} -r")


sherlock = sherlockRepo()



# Core
from fsociety.core.menu import tools_cli

from .cupp import cupp
from .cr3dov3r import cr3dov3r
from .hash_buster import hash_buster
from .changeme import changeme

__tools__ = {
    "cupp": cupp,
    "cr3dov3r": cr3dov3r,
    "hash_buster": hash_buster,
    "changeme": changeme,
}


def cli():
    tools_cli(__name__, __tools__)



import os

from fsociety.core.repo import GitHubRepo
from fsociety.core.menu import confirm


class sqlmapRepo(GitHubRepo):
    def __init__(self, path="sqlmapproject/sqlmap", install=None):
        super().__init__(path=path, install=install)

    def run(self):
        os.chdir(self.full_path)
        user_url = input("\nEnter a url to scan: ").strip()
        args = str()
        if confirm("Do you want to add any extra args?"):
            os.system(f"python3 sqlmap.py --help")
            user_args = input("\nEnter any extra args: ").strip()
        return os.system(f"python3 sqlmap.py -u {user_url} {user_args}")


sqlmap = sqlmapRepo()
